@@ -1,11 +1,11 @@
+import base64
+import zlib
 from collections import defaultdict
 from typing import List, Optional, Tuple, Union
 
-from emmet.core.electronic_structure import (
-    BSPathType,
-    DOSProjectionType,
-    ElectronicStructureDoc,
-)
+import msgpack
+from emmet.core.electronic_structure import BSPathType, DOSProjectionType, ElectronicStructureDoc
+from monty.serialization import MontyDecoder
 from mp_api.core.client import BaseRester, MPRestError
 from pymatgen.analysis.magnetism.analyzer import Ordering
 from pymatgen.core.periodic_table import Element
@@ -79,9 +79,7 @@ class ElectronicStructureRester(BaseRester[ElectronicStructureDoc]):
             query_params.update({"exclude_elements": ",".join(exclude_elements)})
 
         if band_gap:
-            query_params.update(
-                {"band_gap_min": band_gap[0], "band_gap_max": band_gap[1]}
-            )
+            query_params.update({"band_gap_min": band_gap[0], "band_gap_max": band_gap[1]})
 
         if efermi:
             query_params.update({"efermi_min": efermi[0], "efermi_max": efermi[1]})
@@ -97,21 +95,13 @@ class ElectronicStructureRester(BaseRester[ElectronicStructureDoc]):
 
         if sort_fields:
             query_params.update(
-                {"sort_fields": ",".join([s.strip() for s in sort_fields])}
+                {"_sort_fields": ",".join([s.strip() for s in sort_fields])}
             )
 
-        query_params = {
-            entry: query_params[entry]
-            for entry in query_params
-            if query_params[entry] is not None
-        }
+        query_params = {entry: query_params[entry] for entry in query_params if query_params[entry] is not None}
 
         return super().search(
-            num_chunks=num_chunks,
-            chunk_size=chunk_size,
-            all_fields=all_fields,
-            fields=fields,
-            **query_params
+            num_chunks=num_chunks, chunk_size=chunk_size, all_fields=all_fields, fields=fields, **query_params
         )
 
 
@@ -160,9 +150,7 @@ class BandStructureRester(BaseRester):
         query_params["path_type"] = path_type.value
 
         if band_gap:
-            query_params.update(
-                {"band_gap_min": band_gap[0], "band_gap_max": band_gap[1]}
-            )
+            query_params.update({"band_gap_min": band_gap[0], "band_gap_max": band_gap[1]})
 
         if efermi:
             query_params.update({"efermi_min": efermi[0], "efermi_max": efermi[1]})
@@ -178,21 +166,13 @@ class BandStructureRester(BaseRester):
 
         if sort_fields:
             query_params.update(
-                {"sort_fields": ",".join([s.strip() for s in sort_fields])}
+                {"_sort_fields": ",".join([s.strip() for s in sort_fields])}
             )
 
-        query_params = {
-            entry: query_params[entry]
-            for entry in query_params
-            if query_params[entry] is not None
-        }
+        query_params = {entry: query_params[entry] for entry in query_params if query_params[entry] is not None}
 
         return super().search(
-            num_chunks=num_chunks,
-            chunk_size=chunk_size,
-            all_fields=all_fields,
-            fields=fields,
-            **query_params
+            num_chunks=num_chunks, chunk_size=chunk_size, all_fields=all_fields, fields=fields, **query_params
         )
 
     def get_bandstructure_from_task_id(self, task_id: str):
@@ -207,7 +187,7 @@ class BandStructureRester(BaseRester):
         """
 
         result = self._query_resource(
-            criteria={"task_id": task_id, "all_fields": True},
+            criteria={"task_id": task_id, "_all_fields": True},
             suburl="object",
             use_document_model=False,
             num_chunks=1,
@@ -237,55 +217,42 @@ class BandStructureRester(BaseRester):
             bandstructure (Union[BandStructure, BandStructureSymmLine]): BandStructure or BandStructureSymmLine object
         """
 
-        es_rester = ElectronicStructureRester(
-            endpoint=self.base_endpoint, api_key=self.api_key
-        )
+        es_rester = ElectronicStructureRester(endpoint=self.base_endpoint, api_key=self.api_key)
 
         if line_mode:
-            bs_data = es_rester.get_data_by_id(
-                document_id=material_id, fields=["bandstructure"]
-            ).bandstructure
+            bs_data = es_rester.get_data_by_id(document_id=material_id, fields=["bandstructure"]).bandstructure
 
             if bs_data is None:
-                raise MPRestError(
-                    "No {} band structure data found for {}".format(
-                        path_type.value, material_id
-                    )
-                )
+                raise MPRestError("No {} band structure data found for {}".format(path_type.value, material_id))
             else:
                 bs_data = bs_data.dict()
 
             if bs_data.get(path_type.value, None):
                 bs_task_id = bs_data[path_type.value]["task_id"]
             else:
-                raise MPRestError(
-                    "No {} band structure data found for {}".format(
-                        path_type.value, material_id
-                    )
-                )
+                raise MPRestError("No {} band structure data found for {}".format(path_type.value, material_id))
         else:
-            bs_data = es_rester.get_data_by_id(
-                document_id=material_id, fields=["dos"]
-            ).dos
+            bs_data = es_rester.get_data_by_id(document_id=material_id, fields=["dos"]).dos
 
             if bs_data is None:
-                raise MPRestError(
-                    "No uniform band structure data found for {}".format(material_id)
-                )
+                raise MPRestError("No uniform band structure data found for {}".format(material_id))
             else:
                 bs_data = bs_data.dict()
 
             if bs_data.get("total", None):
                 bs_task_id = bs_data["total"]["1"]["task_id"]
             else:
-                raise MPRestError(
-                    "No uniform band structure data found for {}".format(material_id)
-                )
+                raise MPRestError("No uniform band structure data found for {}".format(material_id))
 
         bs_obj = self.get_bandstructure_from_task_id(bs_task_id)
 
         if bs_obj:
-            return bs_obj[0]["data"]
+            b64_bytes = base64.b64decode(bs_obj[0], validate=True)
+            packed_bytes = zlib.decompress(b64_bytes)
+            json_data = msgpack.unpackb(packed_bytes, raw=False)
+            data = MontyDecoder().process_decoded(json_data["data"])
+
+            return data
         else:
             raise MPRestError("No band structure object found.")
 
@@ -304,6 +271,7 @@ class DosRester(BaseRester):
         band_gap: Optional[Tuple[float, float]] = None,
         efermi: Optional[Tuple[float, float]] = None,
         magnetic_ordering: Optional[Ordering] = None,
+        sort_fields: Optional[List[str]] = None,
         num_chunks: Optional[int] = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
@@ -320,6 +288,7 @@ class DosRester(BaseRester):
             band_gap (Tuple[float,float]): Minimum and maximum band gap in eV to consider.
             efermi (Tuple[float,float]): Minimum and maximum fermi energy in eV to consider.
             magnetic_ordering (Ordering): Magnetic ordering of the material.
+            sort_fields (List[str]): Fields used to sort results. Prefix with '-' to sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
@@ -342,9 +311,7 @@ class DosRester(BaseRester):
             query_params["orbital"] = orbital.value
 
         if band_gap:
-            query_params.update(
-                {"band_gap_min": band_gap[0], "band_gap_max": band_gap[1]}
-            )
+            query_params.update({"band_gap_min": band_gap[0], "band_gap_max": band_gap[1]})
 
         if efermi:
             query_params.update({"efermi_min": efermi[0], "efermi_max": efermi[1]})
@@ -352,6 +319,11 @@ class DosRester(BaseRester):
         if magnetic_ordering:
             query_params.update({"magnetic_ordering": magnetic_ordering.value})
 
+        if sort_fields:
+            query_params.update(
+                {"_sort_fields": ",".join([s.strip() for s in sort_fields])}
+            )
+
         query_params = {
             entry: query_params[entry]
             for entry in query_params
@@ -359,11 +331,7 @@ class DosRester(BaseRester):
         }
 
         return super().search(
-            num_chunks=num_chunks,
-            chunk_size=chunk_size,
-            all_fields=all_fields,
-            fields=fields,
-            **query_params
+            num_chunks=num_chunks, chunk_size=chunk_size, all_fields=all_fields, fields=fields, **query_params
         )
 
     def get_dos_from_task_id(self, task_id: str):
@@ -378,7 +346,7 @@ class DosRester(BaseRester):
         """
 
         result = self._query_resource(
-            criteria={"task_id": task_id, "all_fields": True},
+            criteria={"task_id": task_id, "_all_fields": True},
             suburl="object",
             use_document_model=False,
             num_chunks=1,
@@ -401,23 +369,21 @@ class DosRester(BaseRester):
             dos (CompleteDos): CompleteDos object
         """
 
-        es_rester = ElectronicStructureRester(
-            endpoint=self.base_endpoint, api_key=self.api_key
-        )
+        es_rester = ElectronicStructureRester(endpoint=self.base_endpoint, api_key=self.api_key)
 
-        dos_data = es_rester.get_data_by_id(
-            document_id=material_id, fields=["dos"]
-        ).dict()
+        dos_data = es_rester.get_data_by_id(document_id=material_id, fields=["dos"]).dict()
 
         if dos_data["dos"]:
             dos_task_id = dos_data["dos"]["total"]["1"]["task_id"]
         else:
-            raise MPRestError(
-                "No density of states data found for {}".format(material_id)
-            )
+            raise MPRestError("No density of states data found for {}".format(material_id))
 
         dos_obj = self.get_dos_from_task_id(dos_task_id)
         if dos_obj:
-            return dos_obj[0]["data"]
+            b64_bytes = base64.b64decode(dos_obj[0], validate=True)
+            packed_bytes = zlib.decompress(b64_bytes)
+            json_data = msgpack.unpackb(packed_bytes, raw=False)
+            data = MontyDecoder().process_decoded(json_data["data"])
+            return data
         else:
             raise MPRestError("No density of states object found.")
