@@ -1,12 +1,12 @@
 from typing import List, Optional, Tuple, Union
 from pymatgen.core.structure import Structure
 
-from emmet.core.material import MaterialsDoc
+from emmet.core.vasp.material import MaterialsDoc
 from emmet.core.symmetry import CrystalSystem
-from emmet.core.utils import jsanitize
 from emmet.core.settings import EmmetSettings
 
 from mp_api.core.client import BaseRester, MPRestError
+from mp_api.core.utils import validate_ids
 
 _EMMET_SETTINGS = EmmetSettings()
 
@@ -107,7 +107,7 @@ class MaterialsRester(BaseRester[MaterialsDoc]):
             query_params.update({"exclude_elements": ",".join(exclude_elements)})
 
         if task_ids:
-            query_params.update({"task_ids": ",".join(task_ids)})
+            query_params.update({"task_ids": ",".join(validate_ids(task_ids))})
 
         query_params.update(
             {
